$scriptPath = $PSScriptRoot
$desktopPath = [System.Environment]::GetFolderPath('Desktop')
$copySourcePath = Join-Path $scriptPath "copy"
$vmtoolsSourcePath = Join-Path $scriptPath "vmtools"
$installSourcePath = Join-Path $scriptPath "install"
$installScript = Join-Path $installSourcePath "install-stage.ps1"
$computerSystem = Get-CimInstance -ClassName Win32_ComputerSystem
$model = $computerSystem.Model
$manufacturer = $computerSystem.Manufacturer
$isVMware = $model -like "*VMware*" -or $manufacturer -like "*VMware*"
$isVirtualBox = $model -like "*VirtualBox*" -or $manufacturer -like "*VirtualBox*"

# Check if running in VMware or VirtualBox and install the appropriate vmtools
if ($isVMware) {
    $vmwareToolsInstaller = Join-Path $vmtoolsSourcePath "VMware-tools-12.5.1-24649672-x64.exe"
    Start-Process -FilePath $vmwareToolsInstaller -ArgumentList "/S /v /qn REBOOT=R" -Wait
} elseif ($isVirtualBox) {
    $vboxGuestAdditionsInstaller = Join-Path $vmtoolsSourcePath "VBoxWindowsAdditions-amd64.exe"
    $cert = Join-Path $vmtoolsSourcePath "cert"
    Start-Process -FilePath "${cert}\VBoxCertUtil.exe" -ArgumentList "add-trusted-publisher ${cert}\vbox*.cer", "--root ${cert}\vbox*.cer" -Wait;
    Start-Process -FilePath $vboxGuestAdditionsInstaller -ArgumentList '/with_wddm', '/S' -Wait
}

# Copy files to the desktop
if (Test-Path $copySourcePath) {
    Copy-Item -Path "$copySourcePath\*" -Destination $desktopPath -Recurse -Force
}

# Install apps & remove bloated apps
if (Test-Path $installScript) {
    powershell.exe -ExecutionPolicy Bypass -File $installScript
}